"use strict";

import { Animated, Easing } from 'react-native';
import { useCallback, useEffect, useState } from 'react';
import { LinearGradient } from "./LinearGradient.js";
import { jsx as _jsx } from "react/jsx-runtime";
const AnimatedLinearGradient = Animated.createAnimatedComponent(LinearGradient);
export const AnimatedGradient = props => {
  const [color0] = useState(new Animated.Value(0));
  const [color1] = useState(new Animated.Value(0));
  const startAnimation = useCallback(() => {
    const {
      customColors,
      speed
    } = props;
    [color0, color1].forEach(color => color.setValue(0));
    const animation = Animated.loop(Animated.parallel([color0, color1].map(animatedColor => {
      return Animated.timing(animatedColor, {
        toValue: customColors.length,
        duration: customColors.length * speed,
        easing: Easing.linear,
        useNativeDriver: props.useNativeDriver ?? true
      });
    })));
    animation.start();
    return animation;
  }, []);
  useEffect(() => {
    const animation = startAnimation();
    return () => animation.stop();
  }, []);
  const {
    customColors,
    children,
    start,
    end,
    style
  } = props;
  const preferColors = [];
  while (preferColors.length < 2) {
    preferColors.push(customColors.slice(preferColors.length).concat(customColors.slice(0, preferColors.length + 1)));
  }
  const interpolatedColors = [color0, color1].map((animatedColor, index) => {
    return animatedColor.interpolate({
      inputRange: Array.from({
        length: customColors.length + 1
      }, (_, k) => k),
      outputRange: preferColors[index] ?? []
    });
  });
  return /*#__PURE__*/_jsx(AnimatedLinearGradient, {
    gradientStyle: style,
    start: start,
    end: end,
    color0: interpolatedColors[0] ?? '',
    color1: interpolatedColors[1] ?? '',
    children: children
  });
};
//# sourceMappingURL=AnimatedGradient.js.map